@@ -4,11 +4,11 @@ use {
         define,
         errors::{UnpackError, UnpackErrorValue},
     },
-    crate::{config, messages::define::msg_type_id, utils},
+    crate::messages::define::msg_type_id,
     byteorder::{BigEndian, LittleEndian},
     bytes::{BufMut, BytesMut},
     chrono::prelude::*,
-    networkio::bytes_reader::BytesReader,
+    bytesio::bytes_reader::BytesReader,
     std::{cmp::min, collections::HashMap, vec::Vec},
 };
 
@@ -81,23 +81,17 @@ impl ChunkUnpacketizer {
     }
 
     pub fn read_chunks(&mut self) -> Result<UnpackResult, UnpackError> {
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!("\n");
-            print!("\n");
+        let dt = Local::now();
+        log::trace!(
+            "read chunks begin, current time: {}, and read state: {}",
+            dt.timestamp_nanos(),
+            f(&self.chunk_read_state)
+        );
 
-            let dt = Local::now();
-            print!(
-                "read_chunks begin=====+++++++++++++++++++++++++{} {}\n",
-                dt.timestamp_nanos(),
-                f(&self.chunk_read_state)
-            );
-        }
-
-        if config::DEBUG && ((config::SERVER_PUSH & self.session_type) == 0){
-            print!("begin trunks data========\n");
-            utils::print::print(self.reader.get_remaining_bytes());
-            print!("end trunks data========\n");
-        }
+        // log::trace!(
+        //     "read chunks, reader remaining data: {}",
+        //     self.reader.get_remaining_bytes()
+        // );
 
         let mut chunks: Vec<ChunkInfo> = Vec::new();
 
@@ -119,15 +113,11 @@ impl ChunkUnpacketizer {
             }
         }
 
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            let dt = Local::now();
-            print!(
-                "read_chunks end=====+++++++++++++++++++++++++{} {} {}\n",
-                dt.timestamp_nanos(),
-                f(&self.chunk_read_state),
-                chunks.len()
-            );
-        }
+        log::trace!(
+            "read chunks end, current time: {}, and read state: {}",
+            dt.timestamp_nanos(),
+            f(&self.chunk_read_state)
+        );
 
         if chunks.len() > 0 {
             return Ok(UnpackResult::Chunks(chunks));
@@ -150,16 +140,13 @@ impl ChunkUnpacketizer {
         let mut result: UnpackResult = UnpackResult::Empty;
 
         let dt: DateTime<Local> = Local::now();
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!("\n");
-            print!("\n");
-            print!(
-                "read_chunk begin=====+++++++++++++++++++++++++{} {} {}\n",
-                dt.timestamp_nanos(),
-                f(&self.chunk_read_state),
-                self.chunk_index
-            );
-        }
+        log::trace!(
+            "read chunk begin, current time: {}, and read state: {}, and chunk index: {}",
+            dt.timestamp_nanos(),
+            f(&self.chunk_read_state),
+            self.chunk_index,
+        );
+
         self.chunk_index = self.chunk_index + 1;
 
         loop {
@@ -174,12 +161,13 @@ impl ChunkUnpacketizer {
                 }
             };
         }
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!(
-                "read_chunk end  =====+++++++++++++++++++++++++{}\n",
-                dt.timestamp_nanos()
-            );
-        }
+
+        log::trace!(
+            "read chunk end, current time: {}, and read state: {}, and chunk index: {}",
+            dt.timestamp_nanos(),
+            f(&self.chunk_read_state),
+            self.chunk_index,
+        );
         return Ok(result);
 
         // Ok(UnpackResult::Success)
@@ -278,12 +266,11 @@ impl ChunkUnpacketizer {
     }
 
     pub fn read_message_header(&mut self) -> Result<UnpackResult, UnpackError> {
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!(
-                "read_message_header left bytes length ======{}=======\n",
-                self.reader.len()
-            );
-        }
+        log::trace!(
+            "read_message_header, left bytes length: {}",
+            self.reader.len(),
+        );
+
         match self.current_chunk_info.basic_header.format {
             /*****************************************************************/
             /*      5.3.1.2.1. Type 0                                        */
@@ -310,25 +297,19 @@ impl ChunkUnpacketizer {
                             self.current_message_header().msg_length =
                                 self.reader.read_u24::<BigEndian>()?;
 
-                            if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0)
-                            {
-                                print!(
-                                    "msg_length format 0:======{}=======\n",
-                                    self.current_message_header().msg_length
-                                );
-                            }
+                            log::trace!(
+                                "read_message_header format 0, msg_length: {}",
+                                self.current_message_header().msg_length,
+                            );
                             self.msg_header_read_state = MessageHeaderReadState::ReadMsgTypeID;
                         }
                         MessageHeaderReadState::ReadMsgTypeID => {
                             self.current_message_header().msg_type_id = self.reader.read_u8()?;
 
-                            if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0)
-                            {
-                                print!(
-                                    "msg_type_id format 0:======{}=======\n",
-                                    self.current_message_header().msg_type_id
-                                );
-                            }
+                            log::trace!(
+                                "read_message_header format 0, msg_type_id: {}",
+                                self.current_message_header().msg_type_id
+                            );
                             self.msg_header_read_state = MessageHeaderReadState::ReadMsgStreamID;
                         }
                         MessageHeaderReadState::ReadMsgStreamID => {
@@ -367,30 +348,24 @@ impl ChunkUnpacketizer {
                             self.current_message_header().msg_length =
                                 self.reader.read_u24::<BigEndian>()?;
 
-                            if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0)
-                            {
-                                print!(
-                                    "msg_length format 1:======{}=======\n",
-                                    self.current_message_header().msg_length
-                                );
-                            }
+                            log::trace!(
+                                "read_message_header format 1, msg_length: {}",
+                                self.current_message_header().msg_length
+                            );
                             self.msg_header_read_state = MessageHeaderReadState::ReadMsgTypeID;
                         }
                         MessageHeaderReadState::ReadMsgTypeID => {
                             self.current_message_header().msg_type_id = self.reader.read_u8()?;
 
-                            if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0)
-                            {
-                                print!(
-                                    "msg_type_id format 1:======{}=======\n",
-                                    self.current_message_header().msg_type_id
-                                );
-                            }
+                            log::trace!(
+                                "read_message_header format 1, msg_type_id: {}",
+                                self.current_message_header().msg_type_id
+                            );
                             self.msg_header_read_state = MessageHeaderReadState::ReadTimeStamp;
                             break;
                         }
                         _ => {
-                            print!("error happend when read chunk message header\n");
+                            log::error!("error happend when read chunk message header");
                             break;
                         }
                     }
@@ -410,12 +385,10 @@ impl ChunkUnpacketizer {
             +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
             ***************************************************/
             2 => {
-                if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-                    print!(
-                        "msg_type_id format 2:======{}=======\n",
-                        self.current_message_header().msg_type_id
-                    );
-                }
+                log::trace!(
+                    "read_message_header format 2, msg_type_id: {}",
+                    self.current_message_header().msg_type_id
+                );
                 self.current_message_header().timestamp_delta =
                     self.reader.read_u24::<BigEndian>()?;
 
@@ -476,12 +449,11 @@ impl ChunkUnpacketizer {
         let whole_msg_length = self.current_message_header().msg_length as usize;
         let remaining_bytes = whole_msg_length - self.current_chunk_info.payload.len();
 
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!(
-                "whole:{} == remaining:{} \n",
-                whole_msg_length, remaining_bytes
-            );
-        }
+        log::trace!(
+            "read_message_payload whole msg length: {} and remaining bytes: {}",
+            whole_msg_length,
+            remaining_bytes
+        );
 
         let mut need_read_length = remaining_bytes;
         if whole_msg_length > self.max_chunk_size {
@@ -493,21 +465,18 @@ impl ChunkUnpacketizer {
             let additional = need_read_length - remaining_mut;
             self.current_chunk_info.payload.reserve(additional);
         }
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!("buffer len:{}\n", self.reader.len());
-        }
+
+        log::trace!("read_message_payload buffer len:{}", self.reader.len());
 
         let payload_data = self.reader.read_bytes(need_read_length)?;
         self.current_chunk_info
             .payload
             .extend_from_slice(&payload_data[..]);
 
-        if config::DEBUG && ((config::DEBUG_INFO_TYPE & self.session_type) > 0) {
-            print!(
-                "current msg payload len:{}\n",
-                self.current_chunk_info.payload.len()
-            );
-        }
+        log::trace!(
+            "read_message_payload current msg payload len:{}",
+            self.current_chunk_info.payload.len()
+        );
 
         if self.current_chunk_info.payload.len() == whole_msg_length {
             self.chunk_read_state = ChunkReadState::Finish;
