@@ -190,4 +190,12 @@ mod tests {
             }
         }
     }
+
+    use uuid::Uuid;
+
+    #[test]
+    fn test_uuid() {
+        let my_uuid = Uuid::new_v4();
+        println!("{}", my_uuid);
+    }
 }
